pub struct CommandNode {
pub name: String,
pub command: Option<SerializableCommand>,
pub about: Option<String>,
pub children: HashMap<String, CommandNode>,
}Expand description
Represents a node in the command tree
Fields
name: StringName of the command or group
command: Option<SerializableCommand>Command metadata if this is a leaf node (actual command)
about: Option<String>About text for groups
children: HashMap<String, CommandNode>Child nodes (subgroups and commands)
Implementations
Sourceimpl CommandNode
impl CommandNode
Sourcepub fn new_command(name: String, command: AngrealCommand) -> Self
pub fn new_command(name: String, command: AngrealCommand) -> Self
Create a new command node
Sourcepub fn add_command(&mut self, command: AngrealCommand)
pub fn add_command(&mut self, command: AngrealCommand)
Add a command to this node or its children
Sourcepub fn to_project_schema(
&self,
angreal_root: String,
angreal_version: String,
) -> ProjectSchema
pub fn to_project_schema( &self, angreal_root: String, angreal_version: String, ) -> ProjectSchema
Convert to new schema format